@@ -12,20 +12,20 @@ sub _build_ipc {
     my $self = shift;
     require IPC::Open3::Simple;
     return  IPC::Open3::Simple->new(
-        out => sub { $self->callback->('local-output', $_[0]) },
-        err => sub { $self->callback->('local-output', $_[0]) },
+        out => sub { $self->callback->('local-output', $_[0], 'localhost') },
+        err => sub { $self->callback->('local-output', $_[0], 'localhost') },
     ); 
 }
 
 sub run {
     my ($self, @cmd) = @_;
 
-    $self->callback->('command', $self->_stringify(@cmd));
+    $self->callback->('command', $self->_stringify(@cmd), 'localhost');
 
     $self->ipc->run(@cmd);
 
     if ($? != 0) {
-        $self->callback->("error");
+        $self->callback->("error", undef, 'localhost');
         croak "cmd failed";
     }
 };
